const { exec } = require('child_process');

function checkGPTstatus(rqManager) {
    
    const package = 'a3-gpt';
    
    exec(`npm view ${package} version`, (err, stdout, stderr) => {
      if (err) {
        console.error(`${err}\nFailed to check for latest version of ${package}`);
        return;
      }
    
      const latestVersion = stdout.trim();
      const installedVersion = require(`${package}/package.json`).version;
    
      if (latestVersion !== installedVersion) {
        console.log(`New version of ${package} is available: ${latestVersion}\n`);

        // A warning is sent to all players ingame (good way of forcing admins to update the mod)
        // The following syntax is taken from: https://community.bistudio.com/wiki/Structured_Text
        const ingameWarning = `<t shadow='2'><t size='1.5'><t color='#ff3838'>Warning!</t></t>`
                            + `<br/>The current version of DCO-GPT is outdated.<br/><br/>`
                            + `Tell the server admin to update the DCO-GPT.js mod.<br/><br/>`
                            + `<t color='#00ffff'>Current Version: </t><t color='#83ff7f'>${installedVersion}</t><br/>`
                            + `<t color='#00ffff'>Latest Version: </t><t color='#83ff7f'>${latestVersion}</t><br/><br/>`
                            + `Make sure that both the steam workshop mod and the GPT api are up to date!<br/>`
                            + `Only updating one could result in the mod not working properly`;

        rqManager.globalHint(ingameWarning, true);
        rqManager.a3DebugMsg("DCO-GPT is outdated, please update the mod and the GPT api");
      } else {
        const onlineText = `<t shadow='2'><t size='1.5'><t color='#83ff7f'>DCO-GPT is Online</t></t><br/><br/>`
                         + `version: <t color='#00ffff'>${installedVersion}</t><br/><br/>`;
        
        rqManager.globalHint(onlineText);
        console.log(`\n${package} is up to date\n`);
      };
    });

}

module.exports = checkGPTstatus;